import {ExceptionStatusType} from "antd/es/result";
import {FC} from "react";
import {useNavigate, useRouteError} from "react-router-dom";
import {Button, Card, Layout, Result} from "antd";
import {DoadGeneralLayout, DoadHead, doadHeaderStyle, doadLayoutStyles} from "@doad/doad";

const errors: Record<ExceptionStatusType, string> = {
  403: '您没有权限访问当前页面',
  404: '您访问的页面不存在',
  500: '程序出错了',
}

export interface RouteError {
  status?: ExceptionStatusType
  statusText?: string
  message?: string
}

const ErrorPage: FC = () => {
  const error = useRouteError() as RouteError;
  const navigate = useNavigate()

  return (
    <Layout style={{backgroundColor: 'transparent'}}>
      <Layout.Header style={doadHeaderStyle}>
        <DoadHead search />
      </Layout.Header>
      <Layout.Content>
        <DoadGeneralLayout>
          <Card style={{...doadLayoutStyles, textAlign: 'center'}}>
            <Result
              status={error.status ?? 500}
              subTitle={errors[error.status!] ?? (error.statusText || error.message)}
              extra={
                <>
                  <Button onClick={() => navigate(-1)}>上一页</Button>
                  <Button type="primary" onClick={() => navigate('/')}>返回首页</Button>
                </>
              }
            />
          </Card>
        </DoadGeneralLayout>
      </Layout.Content>
    </Layout>
  )
}

ErrorPage.displayName = 'ErrorPage'

export default ErrorPage
