import { FC, ReactNode, StrictMode, useEffect } from 'react'
import ReactDOM from 'react-dom/client'
import dayjs from 'dayjs';
import { RecoilRoot } from 'recoil';
import { RouterProvider } from 'react-router-dom';
import router from './routes/test.tsx';
import {
  AppstoreFilled,
  CodeFilled,
  CompassFilled,
  FireFilled,
  HomeFilled,
  NotificationFilled,
  PieChartFilled,
  SettingFilled,
  TrophyFilled
} from "@ant-design/icons";
import { App } from 'antd'

import {DoadMenuItem, useDoadMenuItemsSetter} from "@doad/doad";

// 关于 Added non-passive event listener to a scroll-blocking ‘wheel’ event. Consider marking event handler as 'passive'
// to make the page more responsive. 的新解决方案
import 'default-passive-events'
import 'dayjs/locale/zh-cn';
import './index.css'

dayjs.locale('zh-cn');

let itemKey = 0

function getItem(
  title: ReactNode,
  icon?: ReactNode,
  children?: DoadMenuItem[],
  path?: string
): DoadMenuItem {
  let handle: DoadMenuItem['handle']
  if (path == null) {
    handle = (_, navigate) => navigate("/abc")
  }
  return {
    key: `${++itemKey}`,
    title,
    icon,
    path,
    handle,
    children,
  }
}

const items: DoadMenuItem[] = [
  getItem("首页", <HomeFilled/>, [
    getItem('工作台', null, [], "/about"),
  ]),
  getItem('管理', <CompassFilled/>, [
    getItem('版本管理'),
    getItem('成员管理'),
    getItem('用户反馈'),
    getItem('付费管理'),
  ]),
  getItem("统计", <PieChartFilled/>),
  getItem('功能', <AppstoreFilled/>, [
    getItem('附近的小程序'),
    getItem('微信搜一搜'),
    getItem('微信支付'),
    getItem('购物订单'),
    getItem('交易保障'),
    getItem('体验评价'),
    getItem('购物订单'),
    getItem('物流服务'),
    getItem('硬件设备'),
    getItem('客服'),
    getItem('订阅消息'),
    getItem('页面内容接入'),
    getItem('小程序插件'),
    getItem('交易组件'),
    getItem('实验工具'),
  ]),

  getItem('开发', <CodeFilled/>, [
    getItem('开发管理'),
    getItem('开发工具'),
    getItem('云服务'),
  ]),

  getItem('成长', <TrophyFilled/>, [
    getItem('小程序评测'),
    getItem('违规记录'),
  ]),

  getItem('推广', <NotificationFilled/>, [
    getItem('流量主'),
    getItem('广告主'),
  ]),

  getItem('第三方服务', <FireFilled/>, [
    getItem('服务'),
  ]),

  getItem('设置', <SettingFilled/>),
];

const Application: FC = () => {
  const setMenus = useDoadMenuItemsSetter()
  useEffect(() => setMenus(items))
  return (
    <App>
      <RouterProvider router={router} />
    </App>
  )
}

ReactDOM.createRoot(document.getElementById('root')!).render(
  <StrictMode>
    <RecoilRoot>
      <Application />
    </RecoilRoot>
  </StrictMode>,
)
