import {Card} from "antd";
import {createBrowserRouter} from "react-router-dom";
import {DoadLazy, DoadTabbedLayout, DoadTabbedLayoutProps} from "@doad/doad";
import AdminLayout from "@/components/layouts/AdminLayout";
import ErrorPage from "@/components/layouts/ErrorPage";

const getTabItem = (label: string, key: string) => {
  return {
    key,
    label,
    render: () => <DoadLazy>{() => {
      return new Promise(resolve => {
        setTimeout(() => {
          resolve({
            default: () => <Card>{label}</Card>
          })
        }, 2000)
      })
    }}</DoadLazy>,
  }
}

const tabsItems: DoadTabbedLayoutProps['items'] = [
  getTabItem('功能异常', '1'),
  getTabItem('产品建议', '2'),
  getTabItem('监控告警', '3'),
  getTabItem('垃圾箱', '4'),
];

const router = createBrowserRouter([
  {
    path: '/',
    element: <AdminLayout/>,
    errorElement: <ErrorPage/>,
    children: [
      {
        path: "about",
        element: (
          <DoadTabbedLayout
            title="用户反馈"
            items={tabsItems}
            activeKey="1"
          />
        )
      },
    ]
  }
])

export default router
