declare namespace API {
  /** 请求参数结构 */
  type Request<
    Query = Record<string, unknown> | string,
    Body = unknown,
    Files = Record<string, Blob | File | string>
  > = {
    /** 请求的目标地址 */
    url: string
    /** HTTP 请求方法，我们可以按照下面列举的方式理解其用法和意义:
     *
     * - GET（SELECT）：从服务器取出资源（一项或多项）。
     * - POST（CREATE）：在服务器新建一个资源。
     * - PUT（UPDATE）：在服务器更新资源（客户端提供改变后的完整资源）。
     * - PATCH（UPDATE）：在服务器更新资源（客户端提供改变的属性）。
     * - DELETE（DELETE）：从服务器删除资源。 */
    method?: 'GET' | 'POST' | 'PUT' | 'PATCH' | 'DELETE'
    /** 搜索参数，对应 URL 的 QueryString 部分，用于对返回结构的过滤，
     * 比如分页参数、排序字段、排序方式及其它。*/
    query?: Query
    /** 请求体数据 */
    body?: Body
    /** 上传的文件 */
    files?: Files
  }

  /** 响应数据结构 */
  type Response<T = unknown> = {
    /** 业务上的请求是否成功 */
    success: boolean
    /** 业务约定的错误码 */
    code: string
    /** 业务上的错误信息 */
    message?: string
    /** 业务数据 */
    data?: T
  }

  /** 分页数据结构 */
  type Pagination<T = unknown> = {
    /** 数据总数 */
    total: number
    /** 当前页码 */
    page: number
    /** 页面数据容量 */
    per_page: number
    /** 数据列表 */
    list: T[]
  }
}
