import {ComponentClass, FunctionComponent} from "react";
import {useDoadPermissionValue} from "../state";
import {getDisplayName, toArray} from "../utils";
import {Link} from "react-router-dom";
import {
  Alert,
  AutoComplete,
  Avatar,
  Badge,
  Button,
  Calendar,
  Card,
  Carousel,
  Cascader,
  Checkbox,
  Collapse,
  ColorPicker,
  DatePicker,
  Descriptions,
  Drawer,
  Dropdown,
  FloatButton,
  Form,
  Image,
  Input,
  InputNumber,
  List,
  Mentions,
  Modal,
  Popconfirm,
  Popover,
  Progress,
  QRCode,
  Radio,
  Rate,
  Segmented,
  Select,
  Slider,
  Statistic,
  Switch,
  Table,
  Tabs,
  Tag,
  Timeline,
  TimePicker,
  Tooltip,
  Tour,
  Transfer,
  Tree,
  TreeSelect,
  Upload
} from "antd";

export type AuthorityComponent<P> = FunctionComponent<P & {
  permissions?: Array<string | number> | string | number
}>

export function withAuthority<P>(BaseComponent: FunctionComponent<P> | ComponentClass<P> | string): AuthorityComponent<P> {
  return function (props) {
    const permissions = useDoadPermissionValue()
    const allows = toArray(props.permissions)
    if (allows == null || permissions.some(x => allows.includes(x.key))) {
      const attributes = {...props}
      delete attributes.permissions
      return <BaseComponent {...attributes} />
    }
    return null
  }
}

function wrap<P>(BaseComponent: FunctionComponent<P> | ComponentClass<P> | string): AuthorityComponent<P>  {
  const Comp = withAuthority<P>(BaseComponent)
  Comp.displayName = `Doad${getDisplayName(BaseComponent)}`
  return Comp
}

export const DoadLink = wrap(Link)
export const DoadButton = wrap(Button)
export const DoadDropdown = wrap(Dropdown)
export const DoadAutoComplete = wrap(AutoComplete)
export const DoadCascader = wrap(Cascader)
export const DoadCheckbox = wrap(Checkbox)
export const DoadColorPicker = wrap(ColorPicker)
export const DoadDatePicker = wrap(DatePicker)
export const DoadForm = wrap(Form)
export const DoadInput = wrap(Input)
export const DoadInputNumber = wrap(InputNumber)
export const DoadMentions = wrap(Mentions)
export const DoadRadio = wrap(Radio)
export const DoadRate = wrap(Rate)
export const DoadSelect = wrap(Select)
export const DoadSlider = wrap(Slider)
export const DoadSwitch = wrap(Switch)
export const DoadTimePicker = wrap(TimePicker)
export const DoadTransfer = wrap(Transfer)
export const DoadTreeSelect = wrap(TreeSelect)
export const DoadUpload = wrap(Upload)
export const DoadAvatar = wrap(Avatar)
export const DoadBadge = wrap(Badge)
export const DoadCalendar = wrap(Calendar)
export const DoadCard = wrap(Card)
export const DoadCarousel = wrap(Carousel)
export const DoadCollapse = wrap(Collapse)
export const DoadDescriptions = wrap(Descriptions)
export const DoadImage = wrap(Image)
export const DoadList = wrap(List)
export const DoadPopover = wrap(Popover)
export const DoadQRCode = wrap(QRCode)
export const DoadSegmented = wrap(Segmented)
export const DoadStatistic = wrap(Statistic)
export const DoadTable = wrap(Table)
export const DoadTabs = wrap(Tabs)
export const DoadTag = wrap(Tag)
export const DoadTimeline = wrap(Timeline)
export const DoadTooltip = wrap(Tooltip)
export const DoadTour = wrap(Tour)
export const DoadTree = wrap(Tree)
export const DoadAlert = wrap(Alert)
export const DoadDrawer = wrap(Drawer)
export const DoadModal = wrap(Modal)
export const DoadPopconfirm = wrap(Popconfirm)
export const DoadProgress = wrap(Progress)
export const DoadFloatButton = wrap(FloatButton)
