import {CSSProperties, FC, ReactNode, useState} from "react";
import {Tabs} from "antd";
import {DoadTitle} from './title'
import {mergeStyles} from "../utils";
import './layout.css'

export const doadLayoutStyles: CSSProperties = {
  maxWidth: '1280px',
  width: '85%',
  margin: '40px auto',
}

export interface DoadGeneralLayoutProps {
  title?: ReactNode
  tailing?: ReactNode
  style?: CSSProperties
  children?: ReactNode
}

export const DoadGeneralLayout: FC<DoadGeneralLayoutProps> = (props) => {
  return (
    <div style={mergeStyles(doadLayoutStyles, props.style)}>
      <DoadTitle title={props.title} tailing={props.tailing} />
      {props.children}
    </div>
  )
}

DoadGeneralLayout.displayName = 'DoadGeneralLayout'

export interface DoadTabbedLayoutTab {
  key: string
  label: string
  disabled?: boolean
  render?: (ready: boolean) => ReactNode
}

export interface DoadTabbedLayoutProps {
  title?: ReactNode
  titleTailing?: ReactNode
  subtitle?: ReactNode
  style?: CSSProperties
  activeKey?: string,
  lazy?: boolean
  animated?: boolean
  items: DoadTabbedLayoutTab[]
}

export const DoadTabbedLayout: FC<DoadTabbedLayoutProps> = (props) => {
  const activeKey = props.activeKey ?? props.items[0]?.key ?? ''
  const [rendered, setRendered] = useState<string[]>([activeKey])
  const tabs = props.items.map((tab) => {
    return {
      key: tab.key,
      label: <span style={{fontSize: '16px'}}>{tab.label}</span>,
      disabled: tab.disabled,
      children: tab.render?.(props.lazy ? rendered.includes(tab.key) : true),
    }
  })
  const handleTabChange = (activeKey: string) => {
    if (props.lazy && !rendered.includes(activeKey)) {
      setRendered((keys) => [...keys, activeKey])
    }
  }

  // fixme 为什么会被渲染2次

  return (
    <DoadGeneralLayout
      title={props.title}
      tailing={props.titleTailing}
      style={props.style}
    >
      {props.subtitle}
      <Tabs
        defaultActiveKey={props.activeKey}
        className="acsRLTLine"
        items={tabs}
        size={'small'}
        animated={props.animated}
        onChange={handleTabChange}
      />
    </DoadGeneralLayout>
  )
}

DoadTabbedLayout.displayName = 'DoadTabbedLayout'
