import {FC, ReactNode, Suspense, createElement, ComponentType, lazy} from "react";
import {Space, Spin} from "antd";

export type LazyFactory<T> = () => Promise<{ default: T }>

export interface DoadLazyProps {
  children?: LazyFactory<ComponentType<unknown>>
  loading?: ReactNode
}

const defaultLoading = (
  <Space align="center" style={{lineHeight: 1, padding: '24px 0'}}>
    <Spin size="small"/>
    <span>加载中...</span>
  </Space>
)

export const DoadLazy: FC<DoadLazyProps> = (props) => {
  if (props.children == null) {
    return null
  }
  return (
    <Suspense fallback={props.loading ?? defaultLoading}>
      {createElement(lazy(props.children))}
    </Suspense>
  )
}

DoadLazy.displayName = 'DoadLazy'
