import {CSSProperties, FC, ReactNode} from "react";
import {Layout} from "antd";
import {DoadSearchProps} from "./search";
import {DoadMenu, DoadMenuProps, doadMenuWidth} from "./menu";
import {DoadHead} from "./head";

export const doadHeaderStyle: CSSProperties = {
  position: 'sticky',
  top: 0,
  zIndex: 3,
  textAlign: 'center',
  height: 64,
  paddingInline: 40,
  lineHeight: '64px',
  backgroundColor: '#ffffff',
  boxShadow: '0 1px 2px rgba(150, 150, 150, 0.3)',
}

export interface DoadRootProps {
  logo?: ReactNode
  footer?: ReactNode
  children?: ReactNode
  search?: DoadSearchProps | boolean
  onMenuClick?: DoadMenuProps['onClick']
}

export const DoadRoot: FC<DoadRootProps> = (props) => {
  return (
    <Layout style={{backgroundColor: 'transparent'}}>
      <Layout.Header style={{...doadHeaderStyle}}>
        <DoadHead search={props.search} logo={props.logo}/>
      </Layout.Header>
      <Layout style={{backgroundColor: 'transparent'}}>
        <Layout.Sider style={{backgroundColor: 'transparent'}} width={doadMenuWidth}>
          <DoadMenu onClick={props.onMenuClick}/>
        </Layout.Sider>
        <Layout.Content>
          {props.children}
        </Layout.Content>
      </Layout>
      {props.footer && <Layout.Footer>
        {props.footer}
      </Layout.Footer>}
    </Layout>
  )
}

DoadRoot.displayName = 'DoadRoot'
