import {
  DefaultValue,
  atom,
  selector,
  useRecoilState,
  useRecoilValue,
  useSetRecoilState
} from "recoil";
import {DoadProfile} from "./types";

export const radProfile = atom<DoadProfile>({
  key: 'acsProfile',
  default: {
    menuItems: [],
    routes: [],
    permissions: [],
  }
})

function createSelector<K extends keyof DoadProfile>(
  key: string,
  field: K,
  defValue?: () => DoadProfile[K],
) {
  return selector<DoadProfile[K]>({
    key,
    get({get}) {
      return get(radProfile)[field]
    },
    set({set}, newValue) {
      set(radProfile, v => ({
        ...v,
        [field]: newValue instanceof DefaultValue ? defValue?.() : newValue,
      }))
    },
  })
}

const activeMenuKeyState = createSelector('doadActiveMenuKeyState', 'activeMenuKey')
const menuItemsState = createSelector('doadMenuItemsState', 'menuItems', () => [])
const userState = createSelector('doadUserState', 'user')
const permissionsState = createSelector('doadPermissionsState', 'permissions', () => [])
const routesState = createSelector('doadRoutesState', 'routes', () => [])

export const useDoadActiveMenuState = () => useRecoilState(activeMenuKeyState)
export const useDoadActiveMenuSetter = () => useSetRecoilState(activeMenuKeyState)
export const useDoadActiveMenuValue = () => useRecoilValue(activeMenuKeyState)
export const useDoadMenuItemsState = () => useRecoilState(menuItemsState)
export const useDoadMenuItemsSetter = () => useSetRecoilState(menuItemsState)
export const useDoadMenuItemsValue = () => useRecoilValue(menuItemsState)
export const useDoadUserState = () => useRecoilState(userState)
export const useDoadUserSetter = () => useSetRecoilState(userState)
export const useDoadUserValue = () => useRecoilValue(userState)
export const useDoadPermissionState = () => useRecoilState(permissionsState)
export const useDoadPermissionSetter = () => useSetRecoilState(permissionsState)
export const useDoadPermissionValue = () => useRecoilValue(permissionsState)
export const useDoadRoutesState = () => useRecoilState(routesState)
export const useDoadRoutesSetter = () => useSetRecoilState(routesState)
export const useDoadRoutesValue = () => useRecoilValue(routesState)
