/** 布局菜单选项 */
export interface DoadMenuItem {
  /** 菜单唯一键 */
  key: string
  /** 菜单标题 */
  title: import('react').ReactNode
  /** 菜单图标 */
  icon?: import('react').ReactNode
  /** 菜单跳转路径 */
  path?: string
  /** 子菜单 */
  children?: DoadMenuItem[]
  /** 自定义点击函数，优先级高于 {@link DoadMenuItem.path} */
  handle?: (item: DoadMenuItem, navigate: import('react-router-dom').NavigateFunction) => void
  /** 其它自定义数据 */
  [key: string]: unknown
}

/** 登录用户信息 */
export interface DoadUser {
  /** 用户昵称 */
  nickname: string
  /** 用户头像 */
  avatar?: string
  /** 其它自定义数据 */
  [key: string]: unknown
}

/** 权限 */
export interface DoadPermission {
  /** 权限唯一键 */
  key: string | number
  /** 权限名称 */
  title?: string
  /** 其它自定义数据 */
  [key: string]: unknown
}


/** 当前用户环境 */
export interface DoadProfile {
  /** 登录的用户信息 */
  user?: DoadUser
  /** 有效的菜单 */
  menuItems: DoadMenuItem[]
  /** 有效的路由 */
  routes: string[]
  /** 被允许的权限 */
  permissions: DoadPermission[]
  /** 当前菜单键 */
  activeMenuKey?: string
}

export type DoadLayoutStatus =
  | 'loading'
  | 'success'
  | 'error'
