// import {Connect} from "vite";
// import IncomingMessage = Connect.IncomingMessage;
// import {ServerResponse} from "http";
// import TypedArray = NodeJS.TypedArray;
//
// export type MockMethod =
//   | 'get'
//   | 'post'
//   | 'put'
//   | 'delete'
//   | 'patch'
//   | 'head'
//   | 'options'
//
// export interface MockContext {
//   params: Record<string, any> | null
//   query: URLSearchParams
//   body: () => Promise<Record<string, any> | null>
//   headers?: Record<string, string>
// }
//
// export interface ServerMockContext extends MockContext {
//   request: IncomingMessage
//   response: ServerResponse
//   json: () => unknown
//   text: () => string
//   buffer: () => TypedArray
// }
//
// export interface MockItem<T = unknown> {
//   url: string
//   method?: MockMethod
//   timeout?: number
//   statusCode?: number
//   response?: (ctx: MockContext) => Promise<T> | T
// }
//
// export type DefineFunction = () => MockItem | MockItem[]
//
// export interface DefineMockOptions {
//   mock?: boolean,
//   setup: DefineFunction
// }
//
// export type DefineOptions =
//   | DefineMockOptions
//   | DefineFunction
//   | MockItem
//   | MockItem[]

import { IncomingMessage, ServerResponse as RawServerResponse } from 'http'

export type MethodType = 'get' | 'post' | 'put' | 'delete' | 'patch'

export interface ServerResponse extends RawServerResponse {
  text(): Promise<string>
  json(): Promise<unknown>
  buffer(): Promise<Uint8Array>
}

export interface MockContext {
  /** 发起请求的路径 */
  url: string
  /** 发起请求的参数 */
  method: string
  /** 路径上面解析到的参数 */
  params: Record<string, any> | null
  /** 解析到的 QueryString 参数 */
  query: URLSearchParams
  /** 提交的报头 */
  headers?: Record<string, string>
  /** 提交的内容 */
  body: () => Promise<Record<string, any> | string | null>
  /** 请求结构，利用服务器端 mock 时有效 */
  request?: IncomingMessage
  /** 响应结构，利用服务器端 mock 时有效 */
  response: ServerResponse
}

export interface MockMethod {
  url: string
  method?: MethodType | MethodType[]
  timeout?: number
  statusCode?: number
  response: (ctx: MockContext) => unknown
}

export type DefineFunction = () => MockMethod | Array<MockMethod>

export interface DefineMockOptions {
  mock?: boolean,
  setup: DefineFunction
}

export type DefineOptions =
  | DefineMockOptions
  | DefineFunction
  | MockMethod
  | Array<MockMethod>
